==> core-1.0.2.tgz: package/lib/fields/checkboxField.js <==
import { Field } from '../field.js';
import { mountElement } from '../utils.js';
export class CheckboxField extends Field {
    constructor(parent, form, options) {
        super(parent, form, options);
        this.options = {
            id: '',
            type: 'checkbox',
            required: false,
            validation: (value, data, required) => {
                if (required && !value)
                    return 'This field is required';
                return true;
            },
            default: null,
            className: 'form-input-checkbox',
            toggle: false,
        };
        this.sliderElement = null;
        this.initializeOptions(options);
        this.onGui();
        this.initialize();
    }
    syncValue() {
        if (this.inputElement && this.inputElement instanceof HTMLInputElement) {
            if (this.getValue() && !this.inputElement.hasAttribute('checked'))
                this.inputElement.setAttribute('checked', String(this.getValue()));
            else if (!this.getValue() && this.inputElement.hasAttribute('checked'))
                this.inputElement.removeAttribute('checked');
        }
    }
    createContainerElement() {
        this.containerElement = document.createElement('div');
        this.containerElement.className = 'form-field ' + this.getType();
        if (this.options.toggle)
            this.containerElement.className += ' is-toggle';
        this.containerElement.setAttribute('id', this.getId() + '_container');
    }
    createLabelElement() {
        this.labelElement = document.createElement('label');
        if (this.inputElement && this.labelElement)
            mountElement(this.inputElement, this.labelElement);
        if (this.sliderElement && this.labelElement)
            mountElement(this.sliderElement, this.labelElement);
        const label = document.createElement('p');
        if (this.options.label)
            label.innerText = this.options.label;
        label.setAttribute('id', this.getId() + '_label');
        this.labelElement.setAttribute('for', this.options.name || this.getId());
        label.className = 'form-field-label';
        if (this.options.label)
            mountElement(label, this.labelElement);
    }
    createInputElement() {
        this.inputElement = document.createElement('input');
        this.inputElement.setAttribute('id', this.getId());
        this.inputElement.setAttribute('name', this.options.name || this.getId());
        this.inputElement.setAttribute('type', this.getType());
        if (this.options.default)
            this.inputElement.setAttribute('checked', String(this.options.default));
        this.inputElement.className = this.options.className;
    }
    createToggleSpan() {
        this.sliderElement = document.createElement('span');
        this.sliderElement.className = 'toggle-slider';
    }
    onGui() {
        this.createContainerElement();
        if (this.options.toggle)
            this.createToggleSpan();
        this.createInputElement();
        this.createLabelElement();
        this.createValidationElement();
        if (this.containerElement && this.labelElement)
            mountElement(this.labelElement, this.containerElement);
        if (this.labelElement && this.validationElement)
            mountElement(this.validationElement, this.labelElement);
    }
    bindChange() {
        if (this.inputElement)
            this.inputElement.addEventListener('change', (event) => {
                this.change(event);
            });
    }
    change(event) {
        this.setValue(event.target.checked);
        if (this.options.change)
            this.options.change(this.getValue());
        this.validate();
    }
}

==> core-1.0.14.tgz: package/lib/fields/checkboxField.js <==
import { Field } from '../field.js';
import { mountElement } from '../utils.js';
export class CheckboxField extends Field {
    constructor(parent, form, options) {
        super(parent, form, options);
        this.options = {
            id: '',
            type: 'checkbox',
            required: false,
            validation: (value, data, required) => {
                if (required && !value)
                    return 'This field is required';
                return true;
            },
            default: null,
            className: 'form-input-checkbox',
            toggle: false,
        };
        this.sliderElement = null;
        this.initializeOptions(options);
        this.onGui();
        this.initialize();
    }
    syncValue() {
        if (this.inputElement && this.inputElement instanceof HTMLInputElement) {
            if (this.getValue() && !this.inputElement.hasAttribute('checked')) {
                this.inputElement.setAttribute('checked', this.getValue());
            }
            else if (!this.getValue() && this.inputElement.hasAttribute('checked'))
                this.inputElement.removeAttribute('checked');
        }
    }
    createContainerElement() {
        this.containerElement = document.createElement('div');
        this.containerElement.className = 'form-field ' + this.getType();
        if (this.options.toggle)
            this.containerElement.className += ' is-toggle';
        this.containerElement.setAttribute('id', this.getId() + '_container');
    }
    createLabelElement() {
        this.labelElement = document.createElement('label');
        if (this.inputElement && this.labelElement)
            mountElement(this.inputElement, this.labelElement);
        if (this.sliderElement && this.labelElement)
            mountElement(this.sliderElement, this.labelElement);
        const label = document.createElement('p');
        if (this.options.label)
            label.innerText = this.options.label;
        label.setAttribute('id', this.getId() + '_label');
        this.labelElement.setAttribute('for', this.options.name || this.getId());
        label.className = 'form-field-label';
        if (this.options.label)
            mountElement(label, this.labelElement);
    }
    createInputElement() {
        this.inputElement = document.createElement('input');
        this.inputElement.setAttribute('id', this.getId());
        this.inputElement.setAttribute('name', this.options.name || this.getId());
        this.inputElement.setAttribute('type', this.getType());
        if (this.options.default)
            this.inputElement.setAttribute('checked', this.options.default);
        this.inputElement.className = this.options.className;
    }
    createToggleSpan() {
        this.sliderElement = document.createElement('span');
        this.sliderElement.className = 'toggle-slider';
    }
    onGui() {
        this.createContainerElement();
        if (this.options.toggle)
            this.createToggleSpan();
        this.createInputElement();
        this.createLabelElement();
        this.createValidationElement();
        if (this.containerElement && this.labelElement)
            mountElement(this.labelElement, this.containerElement);
        if (this.labelElement && this.validationElement)
            mountElement(this.validationElement, this.labelElement);
    }
    bindChange() {
        if (this.inputElement)
            this.inputElement.addEventListener('change', (event) => {
                this.change(event);
            });
    }
    change(event) {
        this.setValue(event.target.checked);
        if (this.options.change)
            this.options.change(this.getValue());
        this.validate();
    }
}
